==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebMRLResizeColumnInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLResizeColumnInfoDescription } from "./WebMRLResizeColumnInfoDescription";
/**
 * @hidden
 */
export let WebMRLResizeColumnInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMRLResizeColumnInfoDescriptionMetadata extends Base {
        static b(a) {
            if (WebMRLResizeColumnInfoDescriptionMetadata.a == null) {
                WebMRLResizeColumnInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMRLResizeColumnInfoDescriptionMetadata.c(WebMRLResizeColumnInfoDescriptionMetadata.a);
            }
            if (a.j(WebMRLResizeColumnInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(WebMRLResizeColumnInfoDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:MRLResizeColumnInfo");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebMRLResizeColumnInfoDescriptionMetadata.b(a);
            a.aa("WebMRLResizeColumnInfo", () => new WebMRLResizeColumnInfoDescription());
            a.z("WebMRLResizeColumnInfo", WebMRLResizeColumnInfoDescriptionMetadata.a);
        }
    }
    WebMRLResizeColumnInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMRLResizeColumnInfoDescriptionMetadata, 'WebMRLResizeColumnInfoDescriptionMetadata');
    WebMRLResizeColumnInfoDescriptionMetadata.a = null;
    return WebMRLResizeColumnInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebMRLResizeColumnInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLResizeColumnInfoDescription } from "./WebMRLResizeColumnInfoDescription";
/**
 * @hidden
 */
export let WebMRLResizeColumnInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMRLResizeColumnInfoDescriptionMetadata extends Base {
        static b(a) {
            if (WebMRLResizeColumnInfoDescriptionMetadata.a == null) {
                WebMRLResizeColumnInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMRLResizeColumnInfoDescriptionMetadata.c(WebMRLResizeColumnInfoDescriptionMetadata.a);
            }
            if (a.k(WebMRLResizeColumnInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebMRLResizeColumnInfoDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:MRLResizeColumnInfo");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebMRLResizeColumnInfoDescriptionMetadata.b(a);
            a.ac("WebMRLResizeColumnInfo", () => new WebMRLResizeColumnInfoDescription());
            a.ab("WebMRLResizeColumnInfo", WebMRLResizeColumnInfoDescriptionMetadata.a);
        }
    }
    WebMRLResizeColumnInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMRLResizeColumnInfoDescriptionMetadata, 'WebMRLResizeColumnInfoDescriptionMetadata');
    WebMRLResizeColumnInfoDescriptionMetadata.a = null;
    return WebMRLResizeColumnInfoDescriptionMetadata;
})();
